@@ -2,9 +2,12 @@ package Net::Google::DocumentsList;
 use Any::Moose;
 use Net::Google::DataAPI;
 use Net::Google::DataAPI::Auth::ClientLogin::Multiple;
+use Net::Google::DocumentsList::Metadata;
+use URI;
+use URI::Escape;
 use 5.008001;
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 with 'Net::Google::DataAPI::Role::Service';
 
@@ -53,6 +56,13 @@ feedurl root_item => (
     is => 'ro',
 );
 
+feedurl change => (
+    entry_class => 'Net::Google::DocumentsList::Change',
+    default => 'https://docs.google.com/feeds/default/private/changes',
+    can_add => 0,
+    is => 'ro',
+);
+
 with 'Net::Google::DocumentsList::Role::HasItems';
 
 around root_items => sub {
@@ -75,6 +85,21 @@ around root_items => sub {
     @items;
 };
 
+sub metadata {
+    my ($self, $args) = @_;
+    my $uri = URI->new(
+        sprintf("https://docs.google.com/feeds/metadata/%s", 
+            uri_escape_utf8(delete $args->{user_id} || 'default')
+        )
+    );
+    $uri->query_form($args);
+    my $atom = eval {$self->get_entry($uri)} or return;
+    Net::Google::DocumentsList::Metadata->new(
+        atom => $atom,
+        service => $self,
+    );
+}
+
 __PACKAGE__->meta->make_immutable;
 
 no Any::Moose;
@@ -147,9 +172,30 @@ parameters are same as 'items' and 'item' methods.
 
 You can not do add_root_item (it's useless). use add_item method instead.
 
+=head2 metadata
+
+you can get metadata of current logged in user. returned object is Net::Google::DocumentsList::Metadata.
+
+  my $meatadata = Net::Google::DocumentsList->new(...)->metadata;
+
+=head2 changes, change
+
+returns Net::Google::DocumentsList::Change objects with calling 'changes', first item of them with 'change'.
+
+  my $service = Net::Google::DocumentsList->new(...);
+  my $changestamp = $service->metadata->largest_changestamp;
+  my @changes = $service->changes(
+    {
+        'start-index' => $changestamp - 10,
+        'max-results' => 10,
+    }
+  );
+
+You can specify 'start-index', 'max-results' parameters to get fewer changes.
+
 =head1 AUTHOR
 
-Noubo Danjou E<lt>nobuo.danjou@gmail.comE<gt>
+Noubo Danjou E<lt>danjou@soffritto.orgE<gt>
 
 =head1 SEE ALSO
 
